@@ -50,7 +50,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <Qt3DCore/qcomponentremovedchange.h>
 #include <Qt3DCore/qnodeid.h>
 #include <Qt3DCore/qpropertyupdatedchange.h>
@@ -110,41 +110,42 @@ enum : int {
     SBK_QT3DCORE_QABSTRACTSKELETON_IDX                       = 5,
     SBK_QT3DCORE_QARMATURE_IDX                               = 6,
     SBK_QT3DCORE_QASPECTENGINE_IDX                           = 7,
-    SBK_QT3DCORE_QASPECTJOB_IDX                              = 8,
-    SBK_QT3DCORE_QBACKENDNODE_IDX                            = 9,
-    SBK_QT3DCORE_QBACKENDNODE_MODE_IDX                       = 10,
-    SBK_QT3DCORE_QCOMPONENT_IDX                              = 11,
-    SBK_QT3DCORE_QCOMPONENTADDEDCHANGE_IDX                   = 12,
-    SBK_QT3DCORE_QCOMPONENTREMOVEDCHANGE_IDX                 = 13,
-    SBK_QT3DCORE_QDYNAMICPROPERTYUPDATEDCHANGE_IDX           = 14,
-    SBK_QT3DCORE_QENTITY_IDX                                 = 15,
-    SBK_QT3DCORE_QJOINT_IDX                                  = 16,
-    SBK_QT3DCORE_QNODE_IDX                                   = 17,
-    SBK_QT3DCORE_QNODE_PROPERTYTRACKINGMODE_IDX              = 18,
-    SBK_QT3DCORE_QNODECOMMAND_IDX                            = 19,
-    SBK_QT3DCORE_QNODECREATEDCHANGEBASE_IDX                  = 20,
-    SBK_QT3DCORE_QNODEDESTROYEDCHANGE_IDX                    = 21,
-    SBK_QT3DCORE_QNODEID_IDX                                 = 22,
-    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 23,
-    SBK_QT3DCORE_QPROPERTYNODEADDEDCHANGE_IDX                = 24,
-    SBK_QT3DCORE_QPROPERTYNODEREMOVEDCHANGE_IDX              = 25,
-    SBK_QT3DCORE_QPROPERTYUPDATEDCHANGE_IDX                  = 26,
-    SBK_QT3DCORE_QPROPERTYUPDATEDCHANGEBASE_IDX              = 27,
-    SBK_QT3DCORE_QPROPERTYVALUEADDEDCHANGE_IDX               = 28,
-    SBK_QT3DCORE_QPROPERTYVALUEADDEDCHANGEBASE_IDX           = 29,
-    SBK_QT3DCORE_QPROPERTYVALUEREMOVEDCHANGE_IDX             = 30,
-    SBK_QT3DCORE_QPROPERTYVALUEREMOVEDCHANGEBASE_IDX         = 31,
-    SBK_QT3DCORE_QSCENECHANGE_IDX                            = 32,
-    SBK_QT3DCORE_QSCENECHANGE_DELIVERYFLAG_IDX               = 33,
+    SBK_QT3DCORE_QASPECTENGINE_RUNMODE_IDX                   = 8,
+    SBK_QT3DCORE_QASPECTJOB_IDX                              = 9,
+    SBK_QT3DCORE_QBACKENDNODE_IDX                            = 10,
+    SBK_QT3DCORE_QBACKENDNODE_MODE_IDX                       = 11,
+    SBK_QT3DCORE_QCOMPONENT_IDX                              = 12,
+    SBK_QT3DCORE_QCOMPONENTADDEDCHANGE_IDX                   = 13,
+    SBK_QT3DCORE_QCOMPONENTREMOVEDCHANGE_IDX                 = 14,
+    SBK_QT3DCORE_QDYNAMICPROPERTYUPDATEDCHANGE_IDX           = 15,
+    SBK_QT3DCORE_QENTITY_IDX                                 = 16,
+    SBK_QT3DCORE_QJOINT_IDX                                  = 17,
+    SBK_QT3DCORE_QNODE_IDX                                   = 18,
+    SBK_QT3DCORE_QNODE_PROPERTYTRACKINGMODE_IDX              = 19,
+    SBK_QT3DCORE_QNODECOMMAND_IDX                            = 20,
+    SBK_QT3DCORE_QNODECREATEDCHANGEBASE_IDX                  = 21,
+    SBK_QT3DCORE_QNODEDESTROYEDCHANGE_IDX                    = 22,
+    SBK_QT3DCORE_QNODEID_IDX                                 = 23,
+    SBK_QT3DCORE_QNODEIDTYPEPAIR_IDX                         = 24,
+    SBK_QT3DCORE_QPROPERTYNODEADDEDCHANGE_IDX                = 25,
+    SBK_QT3DCORE_QPROPERTYNODEREMOVEDCHANGE_IDX              = 26,
+    SBK_QT3DCORE_QPROPERTYUPDATEDCHANGE_IDX                  = 27,
+    SBK_QT3DCORE_QPROPERTYUPDATEDCHANGEBASE_IDX              = 28,
+    SBK_QT3DCORE_QPROPERTYVALUEADDEDCHANGE_IDX               = 29,
+    SBK_QT3DCORE_QPROPERTYVALUEADDEDCHANGEBASE_IDX           = 30,
+    SBK_QT3DCORE_QPROPERTYVALUEREMOVEDCHANGE_IDX             = 31,
+    SBK_QT3DCORE_QPROPERTYVALUEREMOVEDCHANGEBASE_IDX         = 32,
+    SBK_QT3DCORE_QSCENECHANGE_IDX                            = 33,
+    SBK_QT3DCORE_QSCENECHANGE_DELIVERYFLAG_IDX               = 34,
     SBK_QFLAGS_QT3DCORE_QSCENECHANGE_DELIVERYFLAG_IDX        = 1,
-    SBK_QT3DCORE_QSKELETON_IDX                               = 34,
-    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 35,
-    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 36,
-    SBK_QT3DCORE_QSTATICPROPERTYUPDATEDCHANGEBASE_IDX        = 37,
-    SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX     = 38,
-    SBK_QT3DCORE_QSTATICPROPERTYVALUEREMOVEDCHANGEBASE_IDX   = 39,
-    SBK_QT3DCORE_QTRANSFORM_IDX                              = 40,
-    SBK_Qt3DCore_IDX_COUNT                                   = 41
+    SBK_QT3DCORE_QSKELETON_IDX                               = 35,
+    SBK_QT3DCORE_QSKELETONLOADER_IDX                         = 36,
+    SBK_QT3DCORE_QSKELETONLOADER_STATUS_IDX                  = 37,
+    SBK_QT3DCORE_QSTATICPROPERTYUPDATEDCHANGEBASE_IDX        = 38,
+    SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX     = 39,
+    SBK_QT3DCORE_QSTATICPROPERTYVALUEREMOVEDCHANGEBASE_IDX   = 40,
+    SBK_QT3DCORE_QTRANSFORM_IDX                              = 41,
+    SBK_Qt3DCore_IDX_COUNT                                   = 42
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide2_Qt3DCoreTypes;
@@ -176,11 +177,14 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::ChangeFlag >() { return SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_CHANGEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<Qt3DCore::ChangeFlag> >() { return SbkPySide2_Qt3DCoreTypes[SBK_QFLAGS_QT3DCORE_CHANGEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAbstractAspect >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QABSTRACTASPECT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAbstractSkeleton >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QABSTRACTSKELETON_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QArmature >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QARMATURE_IDX]); }
+template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAspectEngine::RunMode >() { return SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QASPECTENGINE_RUNMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAspectEngine >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QASPECTENGINE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QAspectJob >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QASPECTJOB_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QBackendNode::Mode >() { return SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QBACKENDNODE_MODE_IDX]; }
@@ -216,6 +220,7 @@ template<> inline PyTypeObject *SbkType< ::Qt3DCore::QStaticPropertyUpdatedChang
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QStaticPropertyValueAddedChangeBase >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEADDEDCHANGEBASE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QStaticPropertyValueRemovedChangeBase >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QSTATICPROPERTYVALUEREMOVEDCHANGEBASE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::Qt3DCore::QTransform >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_Qt3DCoreTypes[SBK_QT3DCORE_QTRANSFORM_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
