@@ -51,7 +51,7 @@
 #include <pyside2_qtgui_python.h>
 #include <pyside2_qtcore_python.h>
 
-// Binded library includes
+// Bound library includes
 #include <QtSvg/qgraphicssvgitem.h>
 #include <QtSvg/qsvggenerator.h>
 #include <QtSvg/qsvgrenderer.h>
@@ -109,10 +109,13 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+QT_WARNING_PUSH
+QT_WARNING_DISABLE_DEPRECATED
 template<> inline PyTypeObject *SbkType< ::QGraphicsSvgItem >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QGRAPHICSSVGITEM_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSvgGenerator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGGENERATOR_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSvgRenderer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGRENDERER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QSvgWidget >() { return reinterpret_cast<PyTypeObject *>(SbkPySide2_QtSvgTypes[SBK_QSVGWIDGET_IDX]); }
+QT_WARNING_POP
 
 } // namespace Shiboken
 
